@@ -1,6 +1,6 @@
 from exam import fixture
 
-from webtest import TestApp
+from webtest import TestApp as WebtestApp  # prevent pytest-warning
 
 import bottle
 
@@ -25,7 +25,7 @@ def create_app(raven):
     app = bottle.app()
     app.catchall = False
     app = Sentry(app, client=raven)
-    tapp = TestApp(app)
+    tapp = WebtestApp(app)
 
     @bottle.route('/error/', ['GET', 'POST'])
     def an_error():
