@@ -50,6 +50,23 @@ class LoggingIntegrationTest(TestCase):
         self.assertEqual(msg['message'], 'This is a test error')
         self.assertEqual(msg['params'], ())
 
+    def test_logger_ignore_exception(self):
+        class Foo(Exception):
+            pass
+        old = self.client.ignore_exceptions
+        self.client.ignore_exceptions = set(['Foo'])
+        try:
+            try:
+                raise Foo()
+            except Exception:
+                exc_info = sys.exc_info()
+            record = self.make_record('This is a test error',
+                                      exc_info=exc_info)
+            self.handler.emit(record)
+            self.assertEqual(len(self.client.events), 0)
+        finally:
+            self.client.ignore_exceptions = old
+
     def test_can_record(self):
         tests = [
             ("raven", False),
@@ -150,7 +167,6 @@ class LoggingIntegrationTest(TestCase):
         self.assertEqual(frame['module'], 'raven.handlers.logging')
         assert 'exception' not in event
         self.assertTrue('sentry.interfaces.Message' in event)
-        self.assertEqual(event['culprit'], 'root in make_record')
         self.assertEqual(event['message'], 'This is a test of stacks')
 
     def test_no_record_stack(self):
@@ -169,8 +185,6 @@ class LoggingIntegrationTest(TestCase):
         self.assertEqual(len(self.client.events), 1)
         event = self.client.events.pop(0)
         assert 'stacktrace' in event
-        assert 'culprit' in event
-        assert event['culprit'] == 'root in make_record'
         self.assertTrue('message' in event, event)
         self.assertEqual(event['message'], 'This is a test of stacks')
         assert 'exception' not in event
