@@ -3,6 +3,7 @@ from __future__ import with_statement
 import logging
 import webob
 from exam import fixture
+from six import Iterator
 from raven.utils.testutils import TestCase
 
 from raven.base import Client
@@ -21,11 +22,14 @@ class TempStoreClient(Client):
         self.events.append(kwargs)
 
 
-class ErroringIterable(object):
+class ErroringIterable(Iterator):
     def __init__(self):
         self.closed = False
 
     def __iter__(self):
+        return self
+
+    def __next__(self):
         raise ValueError('hello world')
 
     def close(self):
@@ -37,9 +41,27 @@ class ExitingIterable(ErroringIterable):
         self._exc_func = exc_func
 
     def __iter__(self):
+        return self
+
+    def __next__(self):
         raise self._exc_func()
 
 
+class SimpleIteratable(Iterator):
+    def __init__(self):
+        self.closed = False
+        self._iter = iter(['a'])
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        return next(self._iter)
+
+    def close(self):
+        self.closed = True
+
+
 class ExampleApp(object):
     def __init__(self, iterable):
         self.iterable = iterable
@@ -67,9 +89,6 @@ class MiddlewareTestCase(TestCase):
         with self.assertRaises(ValueError):
             response = list(response)
 
-        # TODO: this should be a separate test
-        self.assertTrue(iterable.closed, True)
-
         self.assertEquals(len(self.client.events), 1)
         event = self.client.events.pop(0)
 
@@ -105,9 +124,6 @@ class MiddlewareTestCase(TestCase):
         with self.assertRaises(SystemExit):
             response = list(response)
 
-        # TODO: this should be a separate test
-        self.assertTrue(iterable.closed, True)
-
         self.assertEquals(len(self.client.events), 0)
 
     def test_systemexit_is_captured(self):
@@ -120,9 +136,6 @@ class MiddlewareTestCase(TestCase):
         with self.assertRaises(SystemExit):
             response = list(response)
 
-        # TODO: this should be a separate test
-        self.assertTrue(iterable.closed, True)
-
         self.assertEquals(len(self.client.events), 1)
         event = self.client.events.pop(0)
 
@@ -143,9 +156,6 @@ class MiddlewareTestCase(TestCase):
         with self.assertRaises(KeyboardInterrupt):
             response = list(response)
 
-        # TODO: this should be a separate test
-        self.assertTrue(iterable.closed, True)
-
         self.assertEquals(len(self.client.events), 1)
         event = self.client.events.pop(0)
 
@@ -154,3 +164,13 @@ class MiddlewareTestCase(TestCase):
         self.assertEquals(exc['type'], 'KeyboardInterrupt')
         self.assertEquals(exc['value'], '')
         self.assertEquals(event['level'], logging.ERROR)
+
+    def test_close(self):
+        iterable = SimpleIteratable()
+        app = ExampleApp(iterable)
+        middleware = Sentry(app, client=self.client)
+
+        response = middleware(self.request.environ, lambda *args: None)
+        list(response)  # exhaust iterator
+        response.close()
+        self.assertTrue(iterable.closed, True)
